extern "C"
{
	int jsTestFacInt(void);
	int jsTestFacFloat(void);
	int jsTestFacToggle(void);
	int jsTestFacMenu(void);
	int jsTestFacFile(void);
	int jsTestFacDirSel(void);
	int jsTestFacBitrate(void);
	int jsTestFacBar(void);
	int jsTestFacButton(void);
	int jsTestFacSlider(void);
	int jsTestFacRoText(void);
	int jsTestFacText(void);
	int jsTestFacTab(void);
	int jsTestFacFrame(void);
	int jsTestFacHex(void);
	int jsTestFacMatrix(void);
	int jsTestFacThreadCount(void);
	int jsTestFacNotch(void);
	int jsTestFacEncoding(void);
	int jsTestCrash(void);
	int jsTestAssert(void);
}